#!/usr/bin/python3
"""
    EditData:  A GUI to allow editing of database items.
    Created By Edward Charles Eberle <eberdeed@eberdeed.net>
    October 21, 2016, San Diego California United States of America
"""
import os, sys
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *
from machinetrans.userinterfaces.ui_editdata import Ui_EditData
from machinetrans.helpview import HelpView

class EditData(QDialog, Ui_EditData):
    """ A GUI to allow editing of database items
        generated by the PostgreSQL program.
    """
    
    helpfile = "/usr/share/machinetrans/resources/editdata.html"
    parent = None
    geometry = list()
    winx = 0
    winy = 0
    width1 = 0
    height1 = 0
    
    def __init__(self, parent=None):
        """ Initialize the GUI and place the data in a QTextEditor.
        """
        super(EditData, self).__init__(parent)
        self.setupUi(self)
        self.parent = parent
        self.textEdit.setPlainText(self.parent.data)
        self.acceptBttn.clicked.connect(self.accept)
        self.quitBttn.clicked.connect(self.close)
        self.helpBttn.clicked.connect(self.displayhelp)
        self.textEdit.setPlainText(self.parent.data)
        self.textEdit.setFocus()
        self.setGeometry(self.parent.geometry[0], self.parent.geometry[1], self.parent.geometry[2], self.parent.geometry[3])


    def resizeEvent(self, event):
        """ Resize the GUI and save the sizing data.
        """
        dim = event.size()
        self.height1 = dim.height()
        self.width1 = dim.width()
        tmpwidth = self.width1 - 20
        hscale = self.height1 / 250
        tmpy = 10
        tmpx = self.width1 - 160
        self.helpBttn.setGeometry(tmpx, tmpy, 150, 50)
        self.titleLbl.setGeometry(10, 10, tmpwidth, 25)
        tmpx = 10
        tmpy = 70
        tmpwidth = self.width1 - 20
        tmpheight = self.height1 - 140
        self.textEdit.setGeometry(tmpx, tmpy, tmpwidth, tmpheight)
        tmpy = self.height1 - 60
        tmpx = 160
        self.quitBttn.setGeometry(tmpx, tmpy, 150, 50)
        tmpx = self.width1 - 310
        self.acceptBttn.setGeometry(tmpx, tmpy, 150, 50)
        self.geometry = list([self.winx, self.winy, self.width1, self.height1])
        
    def accept(self):
        """ Pass the edited value to the calling GUI.
        """
        self.parent.data = self.textEdit.toPlainText()
        self.close()
        
    def displayhelp(self):
        """ Display help for this GUI as an HTML page.
        """
        helper = HelpView(self)
        helper.activateWindow()
        helper.exec()
        self.activateWindow()
            
    def closeEvent(self, event):
        """ Close the form. And pass along sizing information.
        """
        self.parent.setGeometry(self.geometry[0], self.geometry[1], self.geometry[2], self.geometry[3])
        event.accept()